@@ -7,7 +7,7 @@ Database schema version control library for SQLAlchemy.
 
 __author__ = 'Chris Miles'
 __copyright__ = '(c) Chris Miles 2008. All rights reserved.'
-__id__ = '$Id: __init__.py 6 2009-02-23 08:47:34Z chris $'
+__id__ = '$Id: __init__.py 8 2009-05-07 14:33:04Z chris $'
 __url__ = '$URL: https://psychofx.com/schemabot/svn/SchemaBot/trunk/schemabot/__init__.py $'
 
 
@@ -192,9 +192,8 @@ class SchemaBot(object):
         if version is None:
             versions = self.changes.keys()
             if not versions:
-                raise SchemaBotError("No schema versions are defined.")
-                
-            if lowest:
+                version = 0
+            elif lowest:
                 version = min(versions)     # smallest version number (excluding 0, the initial version)
             else:
                 version = max(versions)     # largest version number
